:tocdepth: 1

.. |grappelli| replace:: Grappelli
.. |filebrowser| replace:: FileBrowser

.. _releasenotes:

Grappelli 2.8.x Release Notes
=============================

**Grappelli 2.8.x is compatible with Django 1.9**.

Update from Grappelli 2.7.x
---------------------------

* Update Django to 1.9 and check https://docs.djangoproject.com/en/dev/releases/1.9/
* Update Grappelli to 2.8.x
